==> cpes6-project-1.1.8.tgz: package/src/els.js <==
/**
 * Created with WebStorm.
 * @author: jozhua@live.cn
 * @date: 2017/8/1
 * To change this template use File | Settings | File Templates.
 */
let emptyArr = [], slice = emptyArr.slice, classSelectorRE = /^\.([\w-]+)$/,
    idSelectorRE = /^#([\w-]*)$/,
    tagSelectorRE = /^[\w-]+$/, fn = {
        length: 0,
        forEach: emptyArr.forEach,
        indexOf: emptyArr.indexOf,
        concat: emptyArr.concat,
        each (callback) {
            emptyArr.every.call(this, function (el, idx) {
                return callback.call(el, idx, el) !== false
            });
            return this
        },
        map: function (fn) {
            return EL(map(this, function (el, i) {
                return fn.call(el, i, el)
            }))
        },
        get (idx) {
            return idx === undefined ? slice.call(this) : this[idx >= 0 ? idx : idx + this.length]
        }
    };
let E = function (dom, selector) {
    dom = dom || [];
    dom.__proto__ = fn;
    dom.selector = selector || '';
    return dom
}, EL = function (selector) {
    let dom;
    if (!selector) return E();
    else if (isE(selector)) return selector;
    else if (typeof selector == 'string') {
        selector = selector.trim();
        dom = ge(document, selector)
    } else if (isObject(selector)) dom = [selector], selector = null;
    return E(dom, selector);
}, ge = function (element, selector) {
    if (!(element instanceof Node)) element = document;
    let found;
    return (isDocument(element) && idSelectorRE.test(selector)) ? ( (found = element.getElementById(RegExp.$1)) ? [found] : [] ) :
        slice.call(
            classSelectorRE.test(selector) ? element.getElementsByClassName(RegExp.$1) :
                tagSelectorRE.test(selector) ? element.getElementsByTagName(selector) :
                    element.querySelectorAll(selector)
        );
}, isE = function (el) {
    return el instanceof E
}, isDocument = function (obj) {
    return obj != null && obj.nodeType == obj.DOCUMENT_NODE
}, isObject = function (object) {
    return object != null && typeof object === 'object';
}, isArray = function (object) {
    return object != null && object instanceof Array;
}, isFunction = function (object) {
    return object != null && typeof object === 'function';
}, isString = function (object) {
    return typeof object === 'string';
}, extend = function (target, source, deep) {
    for (let key in source) {
        if (deep && (isObject(source[key]) || isArray(source[key]) )) {
            if (isObject(target[key]) && !isObject(target[key])) target[key] = {};
            if (isArray(source[key]) && !isArray(target[key])) target[key] = [];
            extend(target[key], source[key], deep);
        }
        if (source[key] !== undefined) target[key] = source[key];
    }
}, map = function (elements, callback) {
    var value, values = [], i, key;
    if (isArray(elements))
        for (i = 0; i < elements.length; i++) {
            value = callback(elements[i], i)
            if (value != null) values.push(value)
        }
    else
        for (key in elements) {
            value = callback(elements[key], key)
            if (value != null) values.push(value)
        }
    return values.length > 0 ? fn.concat.apply([], values) : values;
};

export default {
    el: function init(selector, context) {
        return EL(selector, context);
    },
    e: E,
    ge: ge,
    isE: isE,
    isObject: isObject,
    isArray: isArray,
    isFunction: isFunction,
    isString: isString,
    isDocument: isDocument,
    fn: fn,
    map: map,
    each: function (elements, callback) {
        let i, key;
        if (isArray(elements)) {
            for (i = 0; i < elements.length; i++)
                if (callback.call(elements[i], i, elements[i]) === false) return elements;
        } else {
            for (key in elements) if (callback.call(elements[key], key, elements[key]) === false) return elements;
        }
        return elements
    },
    eq: function (idx) {
        return this.el(idx === -1 ? this.get(idx) : this.get(idx, +idx + 1))
    },
    extend: function (target) {
        let deep, args = slice.call(arguments, 1);
        if (typeof target == 'boolean') {
            deep = target;
            target = args.shift();
        }
        args.forEach(function (arg) {
            extend(target, arg, deep)
        })
        return target
    },
    ready: function (callback) {
        let $ = this.el;
        if (/complete|loaded|interactive/.test(document.readyState) && document.body) callback($);
        else document.addEventListener('DOMContentLoaded', function () {
            callback($)
        }, false)
    }
}

==> cpes6-project-1.1.9.tgz: package/src/els.js <==
/**
 * Created with WebStorm.
 * @author: jozhua@live.cn
 * @date: 2017/8/1
 * To change this template use File | Settings | File Templates.
 */
let emptyArr = [], slice = emptyArr.slice, classSelectorRE = /^\.([\w-]+)$/,
    idSelectorRE = /^#([\w-]*)$/,
    tagSelectorRE = /^[\w-]+$/, fn = {
        length: 0,
        forEach: emptyArr.forEach,
        indexOf: emptyArr.indexOf,
        concat: emptyArr.concat,
        each (callback) {
            emptyArr.every.call(this, function (el, idx) {
                return callback.call(el, idx, el) !== false
            });
            return this
        },
        map: function (fn) {
            return EL(map(this, function (el, i) {
                return fn.call(el, i, el)
            }))
        },
        get (idx) {
            return idx === undefined ? slice.call(this) : this[idx >= 0 ? idx : idx + this.length]
        },
        eq: function (idx) {
            return EL(idx === -1 ? this.get(idx) : this.get(idx, +idx + 1))
        }
    };
let E = function (dom, selector) {
    dom = dom || [];
    dom.__proto__ = fn;
    dom.selector = selector || '';
    return dom
}, EL = function (selector) {
    let dom;
    if (!selector) return E();
    else if (isE(selector)) return selector;
    else if (typeof selector == 'string') {
        selector = selector.trim();
        dom = ge(document, selector)
    } else if (isObject(selector)) dom = [selector], selector = null;
    return E(dom, selector);
}, ge = function (element, selector) {
    if (!(element instanceof Node)) element = document;
    let found;
    return (isDocument(element) && idSelectorRE.test(selector)) ? ( (found = element.getElementById(RegExp.$1)) ? [found] : [] ) :
        slice.call(
            classSelectorRE.test(selector) ? element.getElementsByClassName(RegExp.$1) :
                tagSelectorRE.test(selector) ? element.getElementsByTagName(selector) :
                    element.querySelectorAll(selector)
        );
}, isE = function (el) {
    return el instanceof E
}, isDocument = function (obj) {
    return obj != null && obj.nodeType == obj.DOCUMENT_NODE
}, isObject = function (object) {
    return object != null && typeof object === 'object';
}, isArray = function (object) {
    return object != null && object instanceof Array;
}, isFunction = function (object) {
    return object != null && typeof object === 'function';
}, isString = function (object) {
    return typeof object === 'string';
}, extend = function (target, source, deep) {
    for (let key in source) {
        if (deep && (isObject(source[key]) || isArray(source[key]) )) {
            if (isObject(target[key]) && !isObject(target[key])) target[key] = {};
            if (isArray(source[key]) && !isArray(target[key])) target[key] = [];
            extend(target[key], source[key], deep);
        }
        if (source[key] !== undefined) target[key] = source[key];
    }
}, map = function (elements, callback) {
    var value, values = [], i, key;
    if (isArray(elements))
        for (i = 0; i < elements.length; i++) {
            value = callback(elements[i], i)
            if (value != null) values.push(value)
        }
    else
        for (key in elements) {
            value = callback(elements[key], key)
            if (value != null) values.push(value)
        }
    return values.length > 0 ? fn.concat.apply([], values) : values;
};

export default {
    el: function init(selector, context) {
        return EL(selector, context);
    },
    e: E,
    ge: ge,
    isE: isE,
    isObject: isObject,
    isArray: isArray,
    isFunction: isFunction,
    isString: isString,
    isDocument: isDocument,
    fn: fn,
    map: map,
    each: function (elements, callback) {
        let i, key;
        if (isArray(elements)) {
            for (i = 0; i < elements.length; i++)
                if (callback.call(elements[i], i, elements[i]) === false) return elements;
        } else {
            for (key in elements) if (callback.call(elements[key], key, elements[key]) === false) return elements;
        }
        return elements
    },
    extend: function (target) {
        let deep, args = slice.call(arguments, 1);
        if (typeof target == 'boolean') {
            deep = target;
            target = args.shift();
        }
        args.forEach(function (arg) {
            extend(target, arg, deep)
        })
        return target
    },
    ready: function (callback) {
        let $ = this.el;
        if (/complete|loaded|interactive/.test(document.readyState) && document.body) callback($);
        else document.addEventListener('DOMContentLoaded', function () {
            callback($)
        }, false)
    }
}
